#!/usr/bin/python
# -*- coding: iso-8859-15 -*-
"""
$Id$

This file is part of the anontwi project, http://anontwi.sourceforge.net.

Copyright (c) 2012/2015 psy <root@lordepsylon.net> - <epsylon@riseup.net>

anontwi is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free
Software Foundation version 3 of the License.

anontwi is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
details.

You should have received a copy of the GNU General Public License along
with anontwi; if not, write to the Free Software Foundation, Inc., 51
Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

Anontwi: Anonymous Twitter Wave Interface
"""
import os, sys, traceback, random
import core.twitter
import core.oauth2 as oauth
import re, urllib2, socket
import core.socks
from urllib2 import URLError
from core.encrypt import Cipher
from core.twitter import TwitterError
from core.options import AnonTwiOptions

try:
    from urlparse import parse_qsl
except:
    from cgi import parse_qsl

# twitter url api
REQUEST_TOKEN_URL = 'https://api.twitter.com/oauth/request_token'
ACCESS_TOKEN_URL  = 'https://api.twitter.com/oauth/access_token'
AUTHORIZATION_URL = 'https://api.twitter.com/oauth/authorize'
SIGNIN_URL        = 'https://api.twitter.com/oauth/authenticate'

# set to emit debug messages about errors (0 = off).
DEBUG = 1

class anontwi(object):
    """
    AnonTwi application class
    """
    def __init__(self):
        # init to AnonTwi
        self.anontwi = []
        self.consumer_key = ''
        self.consumer_secret = ''
        self.num_tweets = 1
        self.proxy = None
        self.isurl = 0
        # setting random user-agent and blank referer for connections
        self.agents = []
        self.agents.append('Mozilla/5.0 (iPhone; U; CPU iOS 2_0 like Mac OS X; en-us)')
        self.agents.append('Mozilla/5.0 (Linux; U; Android 0.5; en-us)')
        self.agents.append('Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0)')
        self.agents.append('Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1)')
        self.agents.append('Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US) AppleWebKit/525.13 (KHTML, like Gecko) Chrome/0.2.149.29 Safari/525.13')
        self.agents.append('Opera/9.25 (Windows NT 6.0; U; en)')
        self.agents.append('Mozilla/2.02E (Win95; U)')
        self.agents.append('Mozilla/5.0 (compatible; Googlebot/2.1; +http://www.google.com/bot.html)')
        self.agents.append('Mozilla/5.0 (compatible; Yahoo! Slurp; http://help.yahoo.com/help/us/ysearch/slurp)')
        self.user_agent = random.choice(self.agents).strip() 
        self.request_headers = {'User-Agent': self.user_agent, 'Referer': ''}

        # take consumer and token: secrets and keys
        from connect_API import APItokens
        for token in APItokens:
            self.consumer_key = token['consumer_key']
            self.consumer_secret = token['consumer_secret']

    def set_options(self, options):
        """
        Set anontwi options
        """
        self.options = options

    def create_options(self, args=None):
        """
        Create the program options for OptionParser.
        """
        self.optionParser = AnonTwiOptions()
        self.options = self.optionParser.get_options(args)
        if not self.options:
            return False
        return self.options

    def try_running(self, func, error, args=None):
        """
        Try running a function and print some error if it fails and exists with
        a fatal error.
        """
        options = self.options
        args = args or []
        try:
            return func(*args)
        except Exception:
            if options.timeline:
                print("This user doesn't exists!!. Aborting..."), "\n"
                sys.exit(2)
            if options.timelinef:
                print"Something wrong fetching timeline of", options.timelinef, "'s friends!!. Aborting...", "\n"
                sys.exit(2)
            if options.retweet:
                print("\nSomething wrong with tweet's ID!!. Aborting..."), "\n"
                sys.exit(2)
            if options.friend:
                print"\nSomething wrong with friendship. Did you sent to", options.friend, "another similar request before?. Aborting...", "\n"
                sys.exit(2)
            #if options.massfriend:
            #    print"\nSomething wrong with massive friendships. Aborting...", "\n"
            #    sys.exit(2)
            if options.dfriend:
                print"\nSomething wrong destroying your friendship. Did you sent to", options.friend, "another similar request before?. Aborting...", "\n"
                sys.exit(2)
            if options.retweet:
                print("\nSomething wrong fetching your mentions. Aborting..."), "\n"
                sys.exit(2)
            else:
                print(error, "error")
                if DEBUG:
                    traceback.print_exc()

    def get_messages(self):
        """
        Get messages to send (Tweet, Image or DM)
        """
        messages = []
        options = self.options
        p = self.optionParser

        if options.tweet:
            if options.dm:
                print('='*75)
                print(str(p.version))
                print('='*75)
                print("Starting to send your DM (direct message)... :)")
                print('='*75)
            elif options.wave:
                print('='*75)
                print(str(p.version))
                print('='*75)
                print("Starting to send your waves... :)")
                print('='*75)
            else:
                print('='*75)
                print(str(p.version))
                print('='*75)
                print("Starting to send your tweet... :)")
                print('='*75)
            messages = [options.tweet]

        #if options.image:
        #    print('='*75)
        #    print(str(p.version))
        #    print('='*75)
        #    print("Starting to send your image... :)")
        #    print('='*75)
        #    messages = [options.image]

        #if options.friend and not (options.tweet or options.image):
        if options.friend and not options.tweet:
            print('='*75)
            print(str(p.version))
            print('='*75)
            print "Creating friendship with:", options.friend, " :)"
            print('='*75)
        elif options.friend:
            print "Creating friendship:", options.friend
            print('='*75)

        #if options.dfriend and not (options.tweet or options.image):
        if options.dfriend and not options.tweet:
            print('='*75)
            print(str(p.version))
            print('='*75)
            print "Destroying friendship with:", options.dfriend, " :)"
            print('='*75)
        elif options.dfriend:
            print "Destroying friendship:", options.dfriend
            print('='*75)

        if options.decaes:
            print('='*75)
            print(str(p.version))
            print('='*75)
            print "Decrypting message... :)"
            print('='*75)

        return messages

    def get_tweetids(self):
        """
        Get messages to send (Tweet, Image or DM)
        """
        tweetids = []
        options = self.options
        p = self.optionParser

        if options.retweet:
            print('='*75)
            print(str(p.version))
            print('='*75)
            print("Starting to reTweet... :)")
            print('='*75)
        return tweetids

    def request_tokens(self):
        """
        Request Access Tokens
        """
        options = self.options
        proxy = options.proxy
        proxy_info = None
        if proxy is not None:
            try:
                match = re.finditer(":",proxy)
                positionlist = []
                for m in match:
                    positionlist.append(m.start())
            
                pos1 = positionlist[0]
                pos2 = positionlist[1]
                host = proxy[pos1+3:pos2]
                slen = len(proxy)
                port = proxy[pos2+1:slen]
                proxy_info = core.socks.setdefaultproxy(core.socks.PROXY_TYPE_HTTP, host, int(port))
                socket.socket = core.socks.socksocket

            except IndexError:
                print "[Error] - Proxy is malformed. For example, to launch with TOR use: --proxy 'http://127.0.0.1:8118'"
                print "\nAborting...\n"
                sys.exit(2)
            except ValueError:
                print "[Error] - Proxy is malformed"
                print "\nAborting...\n"
                sys.exit(2)

        signature_method_hmac_sha1 = oauth.SignatureMethod_HMAC_SHA1()
        oauth_consumer             = oauth.Consumer(key = self.consumer_key, secret = self.consumer_secret)
        oauth_client               = oauth.Client(oauth_consumer, proxy_info = proxy_info)

        print 'Requesting temp token from Twitter'

        try:
            resp, content = oauth_client.request(REQUEST_TOKEN_URL, 'GET', headers=self.request_headers)
        except:
            print "\nConnection refused\n"
            sys.exit(2)

        if resp['status'] != '200':
            print '\nInvalid respond from Twitter requesting temp token: %s' % resp['status'], ':('
            print '\nReview: Connect_API.py to see if your API consumer and token values (secret and key) are correct.\n'
            sys.exit(2)
        else:
            request_token = dict(parse_qsl(content))

        print ''
        print 'Please visit this Twitter page and retrieve the pincode to be used'
        print 'in the next step to obtaining an Authentication Token:'
        print ''
        print '%s?oauth_token=%s' % (AUTHORIZATION_URL, request_token['oauth_token'])
        print ''

        pincode = raw_input('Pincode? ')

        token = oauth.Token(request_token['oauth_token'], request_token['oauth_token_secret'])
        token.set_verifier(pincode)

        print ''
        print 'Generating and signing request for an access token'
        print ''

        oauth_client  = oauth.Client(oauth_consumer, token, proxy_info = proxy_info)
        try:
            resp, content = oauth_client.request(ACCESS_TOKEN_URL, method='POST', body='oauth_verifier=%s' % pincode, headers=self.request_headers)
        except:
            print "\nConnection refused\n"
            sys.exit(2)

        access_token  = dict(parse_qsl(content))

        if resp['status'] != '200':
            print 'The request for a Token did not succeed: %s' % resp['status']
            print access_token
        else:
            print 'Your Twitter Access Token key: %s' % access_token['oauth_token']
            print '          Access Token secret: %s' % access_token['oauth_token_secret']
            print ''

    def send_dm(self, message, dm):
        """
        Send Direct Message (DM)
        """
        options = self.options
        (access_token_key, access_token_secret) = self.get_access_token(options)
        api = core.twitter.Api(self.consumer_key, self.consumer_secret, access_token_key, access_token_secret, proxy=options.proxy, request_headers=self.request_headers)
        try:
            status = api.PostDirectMessage(dm, message)
        except URLError as u:
            print "\n[Error] - ",u.reason.strerror
            sys.exit(2)
        except TwitterError as t:
            try:
                print "\n[Error] - ",t
                sys.exit(2)
            except Exception:
                print "Oops! It seems that you've said that"
                sys.exit(2)

    def send_tweet(self, message):
        """
        Send messages to Twitter
        """
        options = self.options
        (access_token_key, access_token_secret) = self.get_access_token(options)

        api = core.twitter.Api(self.consumer_key, self.consumer_secret, access_token_key, access_token_secret, proxy=options.proxy, request_headers=self.request_headers)
        try:
            status = api.PostUpdate(message)
        except URLError as u:
            print "[Error] - ",u.reason.strerror, "\n"
            sys.exit(2)
        except TwitterError as t:
            print "[Error] - ",t, "\n"
            sys.exit(2)

    def send_wave(self, message):
        """
        Send waves of messages to Twitter
        """
        options = self.options
        (access_token_key, access_token_secret) = self.get_access_token(options)

        api = core.twitter.Api(self.consumer_key, self.consumer_secret, access_token_key, access_token_secret, proxy=options.proxy, request_headers=self.request_headers)
        try:
            status = api.PostUpdates(message)
        except URLError as u:
            print "[Error] - ",u.reason.strerror, "\n"
            sys.exit(2)
        except TwitterError as t:
            print "[Error] - ",t, "\n"
            sys.exit(2)

    def send_retweet(self):
        """
        Send retweets of users by id to Twitter
        """ 
        options = self.options
        (access_token_key, access_token_secret) = self.get_access_token(options)

        api = core.twitter.Api(self.consumer_key, self.consumer_secret, access_token_key, access_token_secret, proxy=options.proxy, request_headers=self.request_headers)
        try:
            status = api.PostRetweet(options.retweet)
        except URLError as u:
            print "[Error] - ",u.reason.strerror, "\n"
            sys.exit(2)
        except TwitterError as t:
            print "[Error] - ",t, "\n"
            sys.exit(2)

#    def send_image(self, message, image):
#        """
#        Send image on Twitpic
#        """
#        options.self.options
#        (access_token_key, access_token_secret) = self.get_access_token(options)
        
#        api = twitpic.TwitPicOAuthClient(self.consumer_key, self.consumer_secret, access_token_key, access_token_secret, proxy=options.proxy, request_headers=self.request_headers)
#        try: 
#            status = api.create("upload", message, image)
#            print(status) 
#        except URLError as u:
#            print "[Error] - ",u.reason.strerror, "\n"
#            sys.exit(2)
#        except TwitterError as t:
#            print "[Error] - ",t, "\n"
#            sys.exit(2)

    def search_messages(self):
        """
        Search messages on Twitter
        """
        options = self.options
        words = options.search.split()
        if len(words) is 2:
            search = words[0]
            num = words[1]
        else:
            search=options.search
            num = 10
 
        (access_token_key, access_token_secret) = self.get_access_token(options)
        api = core.twitter.Api(self.consumer_key, self.consumer_secret, access_token_key, access_token_secret, proxy=options.proxy, request_headers=self.request_headers)
        status = api.GetSearch(search, per_page=num)
        return status

    #def search_topics(self):
    #    """
    #    Search trending topics by country on Twitter
    #    """ 
    #    options = self.options
    #    (access_token_key, access_token_secret) = self.get_access_token(options)

    #    api = core.twitter.Api(self.consumer_key, self.consumer_secret, access_token_key, access_token_secret, proxy=options.proxy)
    #    status = api.GetTrendsCurrent()
    #    return status

    def show_timeline(self):
        """
        Show a number of tweets of a user timeline
        """
        options = self.options
        words = options.timeline.split()
        if len(words) is 2:
            user = words[0]
            num = words[1]
        else:
            user = options.timeline
            num = 10

        (access_token_key, access_token_secret) = self.get_access_token(options)
        api = core.twitter.Api(self.consumer_key, self.consumer_secret, access_token_key, access_token_secret, proxy=options.proxy, request_headers=self.request_headers)
        status = api.GetUserTimeline(user, count=num)
        return status

    def show_timeline_friends(self):
        """ 
        Show a number of tweets of your friends
        """     
        options = self.options
        words = options.timelinef.split()
        if len(words) is 2:
            friend = words[0]
            num = words[1]
        else:
            friend = options.timelinef
            num = 10
                
        (access_token_key, access_token_secret) = self.get_access_token(options)
        api = core.twitter.Api(self.consumer_key, self.consumer_secret, access_token_key, access_token_secret, proxy=options.proxy, request_headers=self.request_headers)           
        status = api.GetFriends(user=friend)
        return status,num

    def show_mentions(self):
        """     
        Show a number of mentions about you
        """     
        options = self.options
        mentions = options.mentions
        (access_token_key, access_token_secret) = self.get_access_token(options) 
        
        api = core.twitter.Api(self.consumer_key, self.consumer_secret, access_token_key, access_token_secret, proxy=options.proxy, request_headers=self.request_headers)
        status = api.GetMentions()
        return status,mentions

#    def set_location(self):
#        """
#        Set your location
#        """
#        options = self.options
#        (access_token_key, access_token_secret) = self.get_access_token(options)

#        api = core.twitter.Api(self.consumer_key, self.consumer_secret, access_token_key, access_token_secret, proxy=options.proxy, request_headers=self.request_headers)
#        status = api.SetLocation(options.location)
#        return status

    def set_friend(self):
        """
        Create a friendship with a user
        """
        options = self.options
        (access_token_key, access_token_secret) = self.get_access_token(options)

        api = core.twitter.Api(self.consumer_key, self.consumer_secret, access_token_key, access_token_secret, proxy=options.proxy, request_headers=self.request_headers)

        #if options.massfriend:
        #    try:
        #        f = open(options.massfriend)
        #        friends = f.readlines()
        #        friends = [ line.replace('\n','') for line in friends ]
        #        f.close()
        #    except:
        #        import os.path
        #        if os.path.exists(options.massfriend) == True:
        #            self.report('\nThere is some errors opening the file: ', options.massfriend, "\n")
        #        else:
        #            self.report('\nThe file: ', options.massfriend, " doesn't exist!!\n")

        #    status = api.CreateFriendship(options.massfriend)
        #else:
        status = api.CreateFriendship(options.friend)

    def remove_friend(self):
        """ 
        Destroy a friendship with a user
        """ 
        options = self.options
        (access_token_key, access_token_secret) = self.get_access_token(options)
            
        api = core.twitter.Api(self.consumer_key, self.consumer_secret, access_token_key, access_token_secret, proxy=options.proxy, request_headers=self.request_headers)   
        status = api.DestroyFriendship(options.dfriend)

    def get_access_token(self, options):
        """
        Get Access Token
        """
        try:
            access_token_key = options.args[0]
        except:
            print "[Error] - you must provide a valid access 'token key'"
            print "\nAborting...\n"
            sys.exit(2) 
        try:
            access_token_secret = options.args[1]
        except:
            print "[Error] - you must provide a valid access 'token secret'"
            print "\nAborting...\n"
            sys.exit(2) 
        return (access_token_key, access_token_secret)
      
    def encrypt(self, messages, key):
        """
        Encrypt messages
        """
        if key is None:
            print "\n[Error] - PIN/Key option (--pin) is required!"
            print "\nAborting...\n"
            sys.exit(2)
        else:
            m_encrypt = set()
            for m in messages:
                e = Cipher(key, m)
                m_enc = e.encrypt()
                m_encrypt.add(m_enc)
            return m_encrypt

    def decrypt(self, messages, key):
        """
        Decrypt messages
        """
        if key is None:
            print "\n[Error] - PIN/Key option (--pin) is required!"
            print "\nAborting...\n"
            sys.exit(2)
        else:
            options = self.options
            # url
            if "https://" in options.decaes:
                match = re.finditer("/", options.decaes)
                positionlist = []
                for m in match:
                    positionlist.append(m.start())
                slen = len(options.decaes)
                try:
                    pos = positionlist[4]
                    id = options.decaes[pos+1:slen]
                
                    (access_token_key, access_token_secret) = self.get_access_token(options)
                    api = core.twitter.Api(self.consumer_key, self.consumer_secret, access_token_key, access_token_secret, proxy=options.proxy, request_headers=self.request_headers)
                    status = api.GetStatus(id)
                    ciphertext = status.text
                except IndexError:
                    print "\n[Error] - URL is not valid"
                    print "\nAborting...\n"
                    sys.exit(2)
                except TwitterError as t:
                    print "\n[Error] - ",t
                    print "\nAborting...\n"
                    sys.exit(2)
            # raw_message
            else:
                ciphertext = options.decaes
         
            key = options.key
            d = Cipher(key, ciphertext)
            plaintext = d.decrypt()
            print "\nPlainText:", plaintext, "\n" 
 
    def run(self, opts=None):
        """ 
        Run AnonTwi
        """ 
        if opts:
            options = self.create_options(opts)
            self.set_options(options)
        options = self.options
        p = self.optionParser

        # step 0: tokens, list searches, timelines, friendships
        if options.tokens:
            print('='*75)
            print(str(p.version))
            print('='*75)
            print("Getting your API tokens (key and secret)...")
            print('='*75), "\n"
            self.try_running(self.request_tokens, "\nInternal error getting access tokens ", ())

        elif options.search:
            print('='*75)
            print(str(p.version))
            print('='*75)
            print("Starting to search: "), options.search
            print('='*75), "\n"
            searches = self.try_running(self.search_messages, "\nInternal error searching -message-. look at the end of this Traceback.")
            print("Results:")
            print("--------")
            for s in searches:
                print "======"
                print "ID:", s.id
                print "-----------"
                print s.created_at
                print "-----------"
                print s.text
                if s.place is not None:
                    print "-----------"
                    print "Location:", s.place["name"]

        #elif options.topics:
        #    print('='*75)
        #    print(str(p.version))
        #    print('='*75)
        #    print("Seaching trending topics (TT) of: "), options.topics
        #    print('='*75), "\n"
        #    trendingtopics = self.try_running(self.search_topics, "\nInternal error searching -trending topic-. look at the end of this Traceback.")

        elif options.mentions:
            print('='*75)
            print(str(p.version))
            print('='*75)
            print("Showing mentions about you...")
            print('='*75), "\n"
            (mentions,count) = self.try_running(self.show_mentions, "\nInternal error searching -mentions- about you. look at the end of this Traceback.")
            print("Mentions:")
            print("---------")
            if count > len(mentions):
                count = len(mentions)
            for i in range(int(count)):
                print "\n======"
                print "Name: ", mentions[i].user.name
                print "-----------"
                print "Created at: ", mentions[i].created_at
                print "-----------"
                print "Status: ", mentions[i].text
                print "======", "\n"

        elif options.timeline:
            print('='*75)
            print(str(p.version))
            print('='*75)
            print("Showing timeline of:"), options.timeline
            print('='*75), "\n"
            timelines = self.try_running(self.show_timeline, "\nInternal error searching -timeline-. look at the end of this Traceback.")
            print("User:"),
            for s in timelines:
                user = s.user.screen_name
            print(user)
            print("Description:"),
            for s in timelines:
                description = s.user.description
            print(description)
            print("Friends:"),
            for s in timelines:
                friends = s.user.friends_count
            print(friends)
            print("Followers:"),
            for s in timelines:
                followers = s.user.followers_count
            print(followers), "\n"
            print "Timeline requests:"
            print("---------")
            for s in timelines:
                print "======"
                print "ID:", s.id
                print "-----------"
                print s.created_at 
                print "-----------"
                print s.text
                if s.place is not None:
                    print "-----------"
                    print "Location:", s.place["name"]

        elif options.timelinef:
            print('='*75)
            print(str(p.version))
            print('='*75)
            print("Showing timeline of the friends of:"), options.timelinef
            print('='*75), "\n"
            (timelinesf,count) = self.try_running(self.show_timeline_friends, "\nInternal error searching -timeline-. look at the end of this Traceback.")
            for i in range(int(count)):
                print("User:"), timelinesf[i].screen_name
                print("Description:"), timelinesf[i].description
                print("Friends:"), timelinesf[i].friends_count
                print("Followers:"), timelinesf[i].followers_count
                print "\n======"
                print "ID:", timelinesf[i].id
                print "-----------"
                print "Created at:", timelinesf[i].created_at
                print "-----------"
                print "Status:", timelinesf[i].status.text
                print "-----------"
                print "Location:", timelinesf[i].name
                print "======", "\n"

        # step 1: get message/image/DM to send and sanitize them
        messages = self.try_running(self.get_messages, "\nInternal error getting -message-. look at the end of this Traceback.")
        #(messages, dm, image) = self.sanitize_messages(messages)
        (messages, dm) = self.sanitize_messages(messages)
       
        # send retweets
        retweets = self.try_running(self.get_tweetids, "\nInternal error sending -retweet-. look at the end of this Traceback.")

        # step 2: de/encryption processes
        if options.encaes:
            key = options.key
            try:
                messages = self.encrypt(messages, key)
            except ValueError:
                print "\n[Error] - AES key must be either 16, 24, or 32 bytes long (ex: 'abcdefghijklmnop')"
                print "\nAborting...\n"
                sys.exit(2)

        if options.decaes:
            key = options.key
            try:
                self.decrypt(messages, key)
            except ValueError:
                print "\n[Error] - AES key must be either 16, 24, or 32 bytes long (ex: 'abcdefghijklmnop')"
                print "\nAborting...\n"
                sys.exit(2)   

        # step 3: send tweet/DM/image, fake gps
        # fake geolocation
        #if options.location:
        #    gps = self.try_running(self.set_location, "\nInternal error sending -Location- ")
        #    print "[Info] Your geolocation place was changed to:", options.location, "\n"

        # send tweet/waves/DM
        if options.tweet and not options.decaes:
            if options.dm:
                dm = self.try_running(self.send_dm, "\nInternal error sending -DM- ", (messages, dm))
                print "[Info] DM sended correctly!", "\n"
            elif options.wave:
                waves = self.try_running(self.send_wave, "\nInternal error sending -Wave- ", messages)
                print "[Info] Waves sended correctly!", "\n"
            else:
                tweet = self.try_running(self.send_tweet, "\nInternal error sending -Tweet- ", messages)
                print "[Info] Tweet sended correctly!", "\n"

        # send image
        #elif options.image:
        #    images = self.try_running(self.send_image, "\nInternal error sending -Image- " (messages, image))
        #    print "[Info] Image uploaded correctly!", "\n"

        # send retweet
        elif options.retweet:
            retweet = self.try_running(self.send_retweet, "\nInternal error sending -reTweet- ", retweets)
            print "[Info] reTweet sended correctly!", "\n"

        # create friendship
        if options.friend:
            friend = self.try_running(self.set_friend, "\nInternal error creating -friendship- ")
            print "[Info] Your request to friendship with:", options.friend, "was successfully sended!", "\n"

        # create massive friendship from file (file.txt)
        #if options.massfriend:
        #    friend = self.try_running(self.set_friend, "\nInternal error creating -friendship- ")
        #    print "[Info] Your request to friendship list was successfully sended!", "\n"

        # destroy friendship
        if options.dfriend:
            dfriend = self.try_running(self.remove_friend, "\nInternal error destroying -friendship- ")
            print "[Info] Your request to destroy friendship with:", options.dfriend, "was successfully sended!", "\n"

    def sanitize_messages(self, messages):
        """
        Sanitize correct input of message/image/dm to send
        """
        options = self.options
        all_messages = set()
        dm_user = set()
        #image = set()

        for message in messages:
            # sanitize image source
            #if options.image:
            #    print "\nImage:", message, "\n"
            #    if "http://" in options.image or "https://" in options.image: #image from url
            #        image.add(options.image)
            #        self.isurl = 1
            #    elif self.isurl == 0: #image from file
            #        (root, ext) = os.path.splitext(message)
            #        if ext != '.gif' and ext != '.jpg' and ext != '.jpeg' and ext != '.png': #by the moment    
            #            print "[Error] - source image file must be: '.gif', '.jpg', '.jpeg' or '.png'\n"
            #            sys.exit(2) 
            #        else:
            #            image.add(options.image)
            #        self.isurl = 0
            #    else:
            #        print "[Error] - source must be an url and start with: 'http://' or 'https://')\n"
            #        sys.exit(2)

            # add tweet message and sanitize DM
            if options.tweet:
                lenght_tweet = len(options.tweet)
                self.num_tweets = int(lenght_tweet/140) + 1 #140 characters/tweet
                print "\nMessage [ Number of words:", lenght_tweet, "- Number of waves:", self.num_tweets, "]"
                print "-------------"
                print options.tweet
                print "-------------"
                all_messages.add(options.tweet)

                if options.dm:
                    if "@" in options.dm:
                        print "\nTo:", options.dm
                        print "------\n"
                        dm_user.add(options.dm)
                    else:
                        print "[Error] - user account must start with: '@' (ex: -d '@nick')\n"
                        sys.exit(2)

            if options.dm and not options.tweet:
                print "\n[Error] - you must enter a message to send, using option -m  (ex: -d '@nick' -m 'text')\n"
                sys.exit(2)

        #return all_messages, dm_user, image
        return all_messages, dm_user

if __name__ == "__main__":
    app = anontwi()
    options = app.create_options()
    if options:
        app.set_options(options)
        app.run()
